include "Dealer.thrift"
include "Vehicle.thrift"

namespace cocoa TCThriftConsumerApp_
namespace java com.truecar.mobile.thrift.consumerapp

/**
 *	<h1>DeleteVehicle API Endpoint.</h1>
 *
 *	This API endpoint is used to remove a vehicle from the saved vehicles of a user. This API endpoint is called during
 *	the synchronization process for any vehicles that have been marked as deleted via the application.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/vehicle/pag/{pag}/user/{userHandle}/id/{vehicleId}/delete
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		POST {basePath}/consumer-app/vehicle/pag/{pag}/user/{userHandle}/id/{vehicleId}/delete HTTP/1.1
 *		Host: {host}
 *		Content-Type: application/octet-stream
 *		Content-Length: 0
 *		Accept: application/octet-stream
 *		X-TrueCar-Token: {secureToken}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/octet-stream
 *		Content-Length: 0
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>PAG_ID_INVALID</li>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *		<li>VEHICLE_ID_INVALID</li>
 *		<li>VEHICLE_NOT_FOUND</li>
 *	</ul>
 *

 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		When a vehicle is deleted in the app, the delete should cascade through options, incentives, chart sets, quotes,
 *		and certificates. The delete should only cascade through dealers that are left no longer referenced by any other
 *		offers or certificates.
 */
struct DeleteVehicleEndpoint {
}

/**
 *	Response for GetUserData API Endpoint.
 *
 *	This API endpoint is used to retrieve all user-specific data for a user. This includes all saved vehicles with their
 *	associated options, incentives, price report content, chart sets, quotes, and certificates. It also includes all
 *	dealers with their associated contacts, perks, photos, videos, and offers.
 *
 *	Note that there is no longer a single top level saved vehicle to which all other data is related. Instead, we treat
 *	both saved vehicles and dealers as top level objects. Certificates now reference dealers by ID instead of containing
 *	a full dealer object. In this way, dealers are no longer duplicated and we can treat offers as completely
 *	independent from saved vehicles.
 *
 *	This API endpoint is called on initial login to download the user-specific data known to the server. It is then
 *	periodically called thereafter to pick up any changes that have occurred on the server via other devices or
 *	browsers.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/user-data/pag/{pag}/user/{userHandle}
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		GET {basePath}/consumer-app/user-data/pag/{pag}/user/{userHandle} HTTP/1.1
 *		Host: {host}
 *		Accept: application/x-thrift
 *		X-TrueCar-Token: {secureToken}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{GetUserDataResponse}
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *	</ul>
 *
 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		This is the "full sync" API. The data in local storage must be updated to exactly match this response, deleting
 *		any entities that are not present in the response.
 */
struct GetUserDataResponse
{
	/**
	 *	All saved vehicles for user.
	 */
	1: optional list<Vehicle.Vehicle> vehicles,
	
	/**
	 *	All dealers for user.
	 *
	 *	A dealer is associated with the user if it associated with any certificates or offers for the user.
	 */
	2: optional list<Dealer.Dealer> dealers,
}

/**
 *	<h1>Request for ScoreOffer API Endpoint.</h1>
 *
 *	This API endpoint is used to set the user score on an offer. If the score is set to 0, the offer should no longer
 *	be returned to the app.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/offer/pag/{pag}/user/{userHandle}/score
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		POST {basePath}/consumer-app/offer/pag/{pag}/user/{userHandle}/score HTTP/1.1
 *		Host: {host}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *		Accept: application/x-thrift
 *		X-TrueCar-Token: {secureToken}
 *
 *		{ScoreOfferRequest}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/octet-stream
 *		Content-Length: 0
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *		<li>OFFER_ID_INVALID</li>
 *		<li>OFFER_NOT_FOUND</li>
 *	</ul>
 *
 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		When an offer is deleted in the app, it should no longer be visible in the app and should be deleted once this
 *		API is called during synchronization.
 */
struct ScoreOfferRequest {
	/**
	 *	Offer ID.
	 */
	1: required string offerId,
	
	/**
	 *	New user score for offer.
	 */
	2: required double score,
}

/**
 *	<h1>Request for SubmitLeads API Endpoint.</h1>
 *
 *	This API endpoint is used to submit leads for a vehicle. Submitting a lead will cause the returned vehicle to
 *	contain a list of certificates, each of which references a returned dealer. Each returned dealer may contain a list
 *	of offers.
 *
 *	This API has no synchronization aspects; the user expects that a failure to connect would not submit the leads. In
 *	the spirit of fat APIs, this API returns the complete affected vehicle; this time with certificates that reference
 *	complete dealers.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/vehicle/pag/{pag}/user/{userHandle}/submit-leads
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		POST {basePath}/consumer-app/vehicle/pag/{pag}/user/{userHandle}/submit-leads HTTP/1.1
 *		Host: {host}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *		Accept: application/x-thrift
 *		X-TrueCar-Token: {secureToken}
 *
 *		{SubmitLeadsRequest}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{SubmitLeadsResponse}
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>QUOTE_ID_INVALID</li>
 *		<li>QUOTE_NOT_FOUND</li>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *		<li>VEHICLE_ID_INVALID</li>
 *		<li>VEHICLE_NOT_FOUND</li>
 *	</ul>
 *
 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		The returned vehicle and dealers are to be merged into local storage. The dealers in the response are just the
 *		dealers for the certificates on the vehicle, so be sure not to remove dealers from local storage that are still
 *		associated with other certificates or offers. That said, after merging this response, orphaned dealers (those
 *		without any certificates or offers) should be removed from local storage.
 */		
struct SubmitLeadsRequest
{
	/**
	 *	ID of vehicle to submit leads for.
	 */
	1: required string vehicleId,
	
	/**
	 *	IDs of quotes to submit leads for.
	 */
	2: required list<i64> quoteIds,
	
	/**
	 *	BPH token.
	 *
	 *	Required for Dealer Selection Algorithm (DSA) feedback. Through this, we know details of the DSA that led to the
	 *	quote for which the user chose to submit a lead.
	 */
	3: required string bphToken,
}

/**
 *	<h1>Response for SubmitLeads API Endpoint.</h1>
 *
 *	This API endpoint is used to submit leads for a vehicle. Submitting a lead will cause the returned vehicle to
 *	contain a list of certificates, each of which references a returned dealer. Each returned dealer may contain a list
 *	of offers.
 *
 *	This API has no synchronization aspects; the user expects that a failure to connect would not submit the leads. In
 *	the spirit of fat APIs, this API returns the complete affected vehicle; this time with certificates that reference
 *	complete dealers.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/vehicle/pag/{pag}/user/{userHandle}/submit-leads
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		POST {basePath}/consumer-app/vehicle/pag/{pag}/user/{userHandle}/submit-leads HTTP/1.1
 *		Host: {host}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *		Accept: application/x-thrift
 *		X-TrueCar-Token: {secureToken}
 *
 *		{SubmitLeadsRequest}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{SubmitLeadsResponse}
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>QUOTE_ID_INVALID</li>
 *		<li>QUOTE_NOT_FOUND</li>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *		<li>VEHICLE_ID_INVALID</li>
 *		<li>VEHICLE_NOT_FOUND</li>
 *	</ul>
 *
 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		The returned vehicle and dealers are to be merged into local storage. The dealers in the response are just the
 *		dealers for the certificates on the vehicle, so be sure not to remove dealers from local storage that are still
 *		associated with other certificates or offers. That said, after merging this response, orphaned dealers (those
 *		without any certificates or offers) should be removed from local storage.
 */		
struct SubmitLeadsResponse
{
	/**
	 *	Updated vehicle.
	 *
	 *	The vehicle will be completely filled in by the server, including all pricing and new certificates.
	 */
	1: required Vehicle.Vehicle vehicle,
	
	/**
	 *	Dealers for certificates associated with the vehicle.
	 *
	 *	The complete set of offers for each dealer in this set is returned from the server and becomes the complete set
	 *	of offers from that dealer.
	 */
	2: required list<Dealer.Dealer> dealers,
	
	/**
	 *	Flag to indicate if this was first ever lead submission for user.
	 *
	 *	Used for analytics.
	 */
	3: optional bool firstLeadSubmission,
}

/**
 *	<h1>Request for UpdateVehicle API Endpoint.</h1>
 *
 *	This API endpoint is used to create or update a saved vehicle for the user. When creating a new saved vehicle, the
 *	vehicleId will be empty in the request, set by the server, and then returned non-empty in the response. This API
 *	endpoint is called during offline storage synchronization for newly added or modified saved vehicle.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/vehicle/pag/{pag}/user/{userHandle}
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		POST {basePath}/consumer-app/vehicle/pag/{pag}/user/{userHandle} HTTP/1.1
 *		Host: {host}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *		Accept: application/x-thrift
 *		X-TrueCar-Token: {secureToken}
 *
 *		{UpdateVehicleRequest}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{UpdateVehicleResponse}
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *		<li>VEHICLE_ID_INVALID</li>
 *		<li>VEHICLE_NOT_FOUND</li>
 *	</ul>
 *
 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		The returned vehicle and dealers are to be merged into local storage. The dealers in the response are just the
 *		dealers for the certificates on the vehicle, so be sure not to remove dealers from local storage that are still
 *		associated with other certificates or offers. That said, after merging this response, orphaned dealers (those
 *		without any certificates or offers) should be removed from local storage.
 */		
struct UpdateVehicleRequest
{
	/**
	 *	New or updated vehicle.
	 *
	 *	Most of the attributes of the vehicle will not be set in this request. See Vehicle object for details.
	 */
	1:required Vehicle.Vehicle vehicle,
}

/**
 *	<h1>Response for UpdateVehicle API Endpoint.</h1>
 *
 *	This API endpoint is used to create or update a saved vehicle for the user. When creating a new saved vehicle, the
 *	vehicleId will be empty in the request, set by the server, and then returned non-empty in the response. This API
 *	endpoint is called during offline storage synchronization for newly added or modified saved vehicle.
 *
 *	URL:
 *	<pre>
 *		{baseUrl}/consumer-app/vehicle/pag/{pag}/user/{userHandle}
 *	</pre>
 *
 *	Request:
 *	<pre>
 *		POST {basePath}/consumer-app/vehicle/pag/{pag}/user/{userHandle} HTTP/1.1
 *		Host: {host}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *		Accept: application/x-thrift
 *		X-TrueCar-Token: {secureToken}
 *
 *		{UpdateVehicleRequest}
 *	</pre>
 *
 *	Response (success):
 *	<pre>
 *		HTTP/1.1 200 OK
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{UpdateVehicleResponse}
 *	</pre>
 *
 *	Response (error):
 *	<pre>
 *		HTTP/1.1 {non200Status}
 *		Content-Type: application/x-thrift
 *		Content-Length: {length}
 *
 *		{Exception}
 *	</pre>
 *
 *	Potential Error Codes:
 *	<ul>
 *		<li>TOKEN_INVALID</li>
 *		<li>TOKEN_EXPIRED</li>
 *		<li>USER_HANDLE_INVALID</li>
 *		<li>USER_NOT_FOUND</li>
 *		<li>VEHICLE_ID_INVALID</li>
 *		<li>VEHICLE_NOT_FOUND</li>
 *	</ul>
 *
 *	<h2>Business Rules and Context</h2>
 *		<h3>Consumers</h3>
 *		<ul>
 *			<li>Consumer Mobile Apps</li>
 *		</ul>
 *
 *	<h2>Implementation Notes:</h2>
 *		<h3>MSP:</h3>
 *
 *		<h3>Apps:</h3>
 *		The returned vehicle and dealers are to be merged into local storage. The dealers in the response are just the
 *		dealers for the certificates on the vehicle, so be sure not to remove dealers from local storage that are still
 *		associated with other certificates or offers. That said, after merging this response, orphaned dealers (those
 *		without any certificates or offers) should be removed from local storage.
 */		
struct UpdateVehicleResponse
{
	/**
	 *	New or updated vehicle.
	 *
	 *	The vehicle will be completely filled in by the server, including all pricing and quotes or certificates.
	 */
	1:required Vehicle.Vehicle vehicle,
	
	/**
	 *	Dealers for any certificates associated with the vehicle.
	 *
	 *	The complete set of offers for each dealer in this set is returned from the server and becomes the complete set
	 *	of offers from that dealer.
	 */
	2:optional list<Dealer.Dealer> dealers,
}
