include "../common/Monetary.thrift"
include "../common/Numeric.thrift"
include "Bucket.thrift"

namespace cocoa TCThriftConsumerApp_
namespace java com.truecar.mobile.thrift.consumerapp

/**
 *	A grouping of chart data elements that are tied to a specific locality. Currently, there are only two chart types:
 *	curves, and histograms.
 */
struct ChartSet {
	/**
	 *	Name of the locality.
	 *
	 *	Naming varies with type:
	 *
	 *	<dl>
	 *		<dt>local</dt>
	 *		<dd>The name takes the form: "City, ST".</dd>
	 *		<dt>regional</dt>
	 *		<dd>The name is a "State".</dd>
	 *		<dt>national</dt>
	 *		<dd>The field is omitted.</dd>
	 *	</dl>
	 */
	1: optional string localityName,
	
	/**
	 *	Average price.
	 */
	2: optional Monetary.UsdCents curveAveragePrice,
	
	/**
	 *	Average percent.
	 *
	 *	Position on curve from 0.00 to 1.00.
	 */
	3: optional double curveAveragePercent,
	
	/**
	 *	Invoice price.
	 */
	4: optional Monetary.UsdCents curveInvoicePrice,
	
	/**
	 *	Invoice percent.
	 *
	 *	Position on curve from 0.00 to 1.00.
	 */
	5: optional double curveInvoicePercent,
	
	/**
	 *	MSRP.
	 */
	6: optional Monetary.UsdCents curveMsrpPrice,
	
	/**
	 *	MSRP percent.
	 *
	 *	Position on curve from 0.00 to 1.00.
	 */
	7: optional double curveMsrpPercent,
	
	/**
	 *	Callout price.
	 */
	8: optional Monetary.UsdCents curveCalloutPrice,
	
	/**
	 *	Callout percent.
	 */
	9: optional double curveCalloutPercent,
	
	/**
	 *	Minimum value for a "great" price.
	 *
	 *	This is the least value for the great price region; values immediately below this are part of the "below market"
	 *	price region.
	 */
	10: optional Monetary.UsdCents curveGreatMinimum,
	
	/**
	 *	Minimum value for a "good" price.
	 *
	 *	This is the least value for the good price region; values immediately below this are part of the "great" price
	 *	region.
	 */
	11: optional Monetary.UsdCents curveGoodMinimum,
	
	/**
	 *	Minimum value for an above-market price.
	 *
	 *	This is the least value for the above-market region; values immediately below this are part of the "good" price
	 *	region.
	 */
	12: optional Monetary.UsdCents curveAboveMarketMinimum,

	/**
	 *	Statistical certainty.
	 *
	 *	This is the statistical certainty of the pricing information based on sample size, recency, and accuracy.  
	 */
	13: optional double curveConfidence,
	
	/**
	 *	Margin of variability.
	 *
	 *	This value denotes the margin of variability between average paid and market average. That is, TrueCar is
	 *	'confidence' confident that the average paid is within 'confidenceWithin' percent of the market average.  
	 */
	14: optional double curveConfidenceWithin,
	
	/**
	 *	Number of days in histogram data.
	 */
	15: optional i16 histogramHistoricalDays,
	
	/**
	 *	Total transaction count in histogram.
	 */
	16: optional i32 histogramTransactionCount,
	
	/**
	 *	Histogram data.
	 */
	17: optional list<Bucket.Bucket> histogramBuckets,
}
