include "../common/Monetary.thrift"
include "PriceExperience.thrift"
include "../common/DealerFeeOrAccessory.thrift"
include "../common/PriceEmphasis.thrift"

namespace cocoa TCThriftConsumerApp_
namespace java com.truecar.mobile.thrift.consumerapp

/**
 *	Quote.
 *
 *	A saved vehicle for which leads have not been submitted, and thus has no certificates, may, and usually will, have a
 *	list of quotes. Each quote is a potential certificate and becomes so when the user chooses to submit a lead for the
 *	quote.
 *
 *	Note: in the prior version of the API, a VehicleDeal represented both a quote and a certificate as now defined. The
 *	difference was in the presence of the dealer details and the isLeadSubmitted flag. This change makes quotes much
 *	lighter-weight now.
 */
struct Quote
{
	/**
	 *	Quote ID.
	 */
	1: required i64 quoteId,
	
	/**
	 *	Pre-selected flag.
	 */
	2: optional bool preselected,

	/**
	 *	Distance from search ZIP Code in miles.
	 */
	3: optional double distanceMiles,
	
	/**
	 *	Driving distance from search ZIP Code in miles.
	 */
	4: optional double drivingDistanceMiles,
	
	/**
	 *	Price experience.
	 */
	5: optional PriceExperience.PriceExperience priceExperience,
	
	/**
	 *	Price type.
	 */
	6: optional string priceType,

	/**
	 *	Total price before fees.
	 *
	 *	If not set, dealer will provide price. For target price experience, should be equal to vehicle.totalEstimate.
	 */
	7: optional Monetary.UsdCents priceBeforeFeesOrAccessories,

	/**
	 *	Price.
	 *
	 *	This may be the same as totalPrice. We only use this field in analytics and should check MSP implementation to
	 *	see if it can be removed.
	 */
	8: optional Monetary.UsdCents price,
	
	/**
	 *	Total savings from MSRP.
	 *
	 *	totalSavings = totalMsrp - totalPrice. If totalPrice > totalMsrp, totalSavings will be negative.
	 */
	9: optional Monetary.UsdCents totalSavings,

	/**
	 *	Estimated savings.
	 *
	 *	This may be the same as totalSavings. We only use this field in analytics and should check MSP implementation to
	 *	see if it can be removed.
	 */
	10: optional Monetary.UsdCents estimatedSavings,

	/**
	 *	Documentation fee.
	 */
	11: optional Monetary.UsdCents deprecatedDocumentationFee,
	
	/**
	 *	Maximum allowed documentation fee for state.
	 */
	12: optional Monetary.UsdCents deprecatedMaxStateDocumentationFee,
	
	/**
	 *	Documentation fee name.
	 */
	13: optional string deprecatedDocumentationFeeName,
	
	/**
     *	List of dealer fees.
     */
    14: optional list<DealerFeeOrAccessory.DealerFeeOrAccessory> dealerFeesAndAccessories,

	/**
     * Dealer transparency pledge.
     */
    15: optional bool dealerTransparencyPledge,
    
    /**
     * This value indicates the price to emphasize on. e.g. price, price + dealer installed options + doc fee etc.
     *
     */
    16: optional PriceEmphasis.PriceEmphasis priceEmphasis,
    
	/**
	 *	Price total with fees.
	 */
	17: optional Monetary.UsdCents priceWithFeesAndAccessories,    
	
	/**
	 * Fees total.
	 */
	18: optional Monetary.UsdCents totalFeesAndAccessories,
	
	/**
     * Whether or not the transparency pledge badge should be shown (note this is different than the dealerTransparencyPledge flag).
     */
    19: optional bool showDealerTransparencyPledge,
}
