CREATE TABLE AnalyticsEvent
(
    _id INTEGER PRIMARY KEY NOT NULL,
    bundleId TEXT,
    event TEXT,
    pageName TEXT,
    params TEXT,
    timestamp TEXT
);
CREATE TABLE Bucket
(
    _id INTEGER PRIMARY KEY NOT NULL,
    maximumPrice INTEGER NOT NULL,
    minimumPrice INTEGER NOT NULL,
    transactionCount INTEGER NOT NULL,
    chartSetRowId INTEGER NOT NULL,
    FOREIGN KEY (chartSetRowId) REFERENCES ChartSet (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Certificate
(
    _id INTEGER PRIMARY KEY NOT NULL,
    baseMsrp INTEGER,
    baseSavings INTEGER,
    certificateId TEXT NOT NULL,
    dealerId INTEGER NOT NULL,
    destinationFee INTEGER,
    distanceMiles REAL,
    documentationFee INTEGER,
    documentationFeeName TEXT,
    drivingDistanceMiles REAL,
    estimatedLicensePrice INTEGER,
    estimatedRegistrationPrice INTEGER,
    estimatedSavings INTEGER,
    estimatedTaxPrice INTEGER,
    estimatedTitlePrice INTEGER,
    expirationDate TEXT,
    maxStateDocumentationFee INTEGER,
    optionsMsrp INTEGER,
    optionsSavings INTEGER,
    price INTEGER,
    priceExperience INTEGER,
    priceType TEXT,
    quoteId TEXT,
    sequence INTEGER,
    specialFeesInvoiceTotal INTEGER,
    syncId TEXT,
    totalMsrp INTEGER,
    totalPrice INTEGER,
    totalSavings INTEGER,
    dealerRowId INTEGER,
    vehicleRowId INTEGER,
    FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE ChartSet
(
    _id INTEGER PRIMARY KEY NOT NULL,
    curveAboveMarketMinimum INTEGER,
    curveAveragePercent REAL,
    curveAveragePrice INTEGER,
    curveCalloutPercent REAL,
    curveCalloutPrice INTEGER,
    curveConfidence REAL,
    curveConfidenceWithin REAL,
    curveGoodMinimum INTEGER,
    curveGreatMinimum INTEGER,
    curveInvoicePercent REAL,
    curveInvoicePrice INTEGER,
    curveMsrpPercent REAL,
    curveMsrpPrice INTEGER,
    histogramHistoricalDays INTEGER,
    histogramTransactionCount INTEGER,
    localityName TEXT,
    localityType INTEGER,
    vehicleRowId INTEGER,
    FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Contact
(
    _id INTEGER PRIMARY KEY NOT NULL,
    contactId INTEGER NOT NULL,
    email TEXT,
    imageUrl TEXT,
    name TEXT,
    phone TEXT,
    quote TEXT,
    sequence INTEGER,
    title TEXT,
    certificateRowId INTEGER,
    dealerRowId INTEGER,
    offerRowId INTEGER,
    priceCheckRowId INTEGER,
    FOREIGN KEY (priceCheckRowId) REFERENCES PriceCheck (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (offerRowId) REFERENCES Offer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (certificateRowId) REFERENCES Certificate (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Dealer
(
    _id INTEGER PRIMARY KEY NOT NULL,
    aboutDealershipUrl TEXT,
    city TEXT,
    dealerId INTEGER NOT NULL,
    dealerType INTEGER,
    facebookUrl TEXT,
    hoursDaylightSavingsTimeObserver INTEGER,
    hoursFridayCloseTime TEXT,
    hoursFridayOpenTime TEXT,
    hoursMondayCloseTime TEXT,
    hoursMondayOpenTime TEXT,
    hoursSaturdayCloseTime TEXT,
    hoursSaturdayOpenTime TEXT,
    hoursSundayCloseTime TEXT,
    hoursSundayOpenTime TEXT,
    hoursThursdayCloseTime TEXT,
    hoursThursdayOpenTime TEXT,
    hoursTuesdayCloseTime TEXT,
    hoursTuesdayOpenTime TEXT,
    hoursUtcOffsetMillis INTEGER,
    hoursWednesdayCloseTime TEXT,
    hoursWednesdayOpenTime TEXT,
    inventoryUrl TEXT,
    latitude REAL,
    lifetimeSalesTotal INTEGER,
    longitude REAL,
    makeId INTEGER,
    makeName TEXT,
    name TEXT,
    phone TEXT,
    postalCode TEXT,
    priceCheckEnabled INTEGER,
    state TEXT,
    streetAddress1 TEXT,
    streetAddress2 TEXT,
    twitterUrl TEXT,
    usedInventoryUrl TEXT,
    websiteUrl TEXT
);
CREATE TABLE Incentive
(
    _id INTEGER PRIMARY KEY NOT NULL,
    amount INTEGER,
    dealerId INTEGER,
    desc TEXT,
    endDate TEXT,
    incentiveId INTEGER NOT NULL,
    incentiveType INTEGER,
    isIncludedInGuaranteedSavings INTEGER,
    name TEXT,
    preselected INTEGER,
    startDate TEXT,
    offerRowId INTEGER,
    priceCheckRowId INTEGER,
    vehicleRowId INTEGER,
    FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (priceCheckRowId) REFERENCES PriceCheck (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (offerRowId) REFERENCES Offer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Offer
(
    _id INTEGER PRIMARY KEY NOT NULL,
    additionalIncentivesTotal INTEGER,
    bannerType INTEGER,
    baseMsrpAmount INTEGER,
    bodyStyle TEXT,
    dealerInstalledOptionsTotal INTEGER,
    destinationFee INTEGER,
    displayStatus INTEGER,
    documentationFee INTEGER,
    documentationFeeName TEXT,
    driveType TEXT,
    engine TEXT,
    estimatedLicensePrice INTEGER,
    estimatedRegistrationPrice INTEGER,
    estimatedTaxPrice INTEGER,
    estimatedTitlePrice INTEGER,
    expirationDate TEXT,
    exteriorColorName TEXT,
    features TEXT,
    fuel TEXT,
    guaranteedSavings INTEGER,
    imageUrl TEXT,
    interiorColorName TEXT,
    makeId INTEGER,
    makeName TEXT,
    maxStateDocumentationFee INTEGER,
    mileage INTEGER,
    modelId INTEGER,
    modelName TEXT,
    msrpTotal INTEGER,
    offerId TEXT NOT NULL,
    oneTimeSavingsPrice INTEGER,
    optionsMsrpTotal INTEGER,
    priceTotal INTEGER,
    quoteId TEXT,
    regionalFeesPrice INTEGER,
    savings INTEGER,
    savingsPercent REAL,
    sequence INTEGER,
    specialFeesInvoiceTotal INTEGER,
    trimId INTEGER,
    trimName TEXT,
    vehicleType INTEGER,
    vin TEXT,
    year INTEGER,
    dealerRowId INTEGER,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Option
(
    _id INTEGER PRIMARY KEY NOT NULL,
    category TEXT,
    desc TEXT,
    invoicePrice INTEGER,
    msrpPrice INTEGER,
    name TEXT,
    optionId INTEGER NOT NULL,
    state INTEGER,
    trimDependentOptionId INTEGER NOT NULL,
    offerRowId INTEGER,
    priceCheckRowId INTEGER,
    vehicleRowId INTEGER,
    FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (priceCheckRowId) REFERENCES PriceCheck (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
    FOREIGN KEY (offerRowId) REFERENCES Offer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Perk
(
    _id INTEGER PRIMARY KEY NOT NULL,
    desc TEXT,
    iconType INTEGER,
    perkId INTEGER NOT NULL,
    title TEXT,
    dealerRowId INTEGER,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Photo
(
    _id INTEGER PRIMARY KEY NOT NULL,
    imageUrl TEXT,
    photoId INTEGER NOT NULL,
    sequence INTEGER,
    dealerRowId INTEGER,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE PriceCheck
(
    _id INTEGER PRIMARY KEY NOT NULL,
    additionalFees INTEGER,
    additionalIncentivesTotal INTEGER,
    baseMsrpAmount INTEGER,
    dealerInstalledOptions TEXT,
    dealerInstalledOptionsTotal INTEGER,
    destinationFee INTEGER,
    documentationFee INTEGER,
    documentationFeeIsEditable INTEGER NOT NULL,
    documentationFeeName TEXT,
    estimatedLicensePrice INTEGER,
    estimatedRegistrationPrice INTEGER,
    estimatedTaxPrice INTEGER,
    estimatedTitlePrice INTEGER,
    expirationDate TEXT,
    exteriorColorName TEXT,
    features TEXT,
    fuel TEXT,
    guaranteedSavings INTEGER,
    id TEXT NOT NULL,
    imageUrl TEXT,
    interiorColorName TEXT,
    license INTEGER,
    makeId INTEGER,
    makeName TEXT,
    maxStateDocumentationFee INTEGER,
    modelId INTEGER,
    modelName TEXT,
    msrpTotal INTEGER,
    notes TEXT,
    optionsMsrpTotal INTEGER,
    priceTotal INTEGER,
    regionalFeesPrice INTEGER,
    savings INTEGER,
    savingsPercent REAL,
    taxPercent INTEGER,
    timestamp TEXT NOT NULL,
    title INTEGER,
    totalRetailPrice INTEGER,
    trimId INTEGER,
    trimName TEXT,
    vehicleType INTEGER,
    vin TEXT,
    year INTEGER,
    dealerRowId INTEGER,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Quote
(
    _id INTEGER PRIMARY KEY NOT NULL,
    distanceMiles REAL,
    documentationFee INTEGER,
    documentationFeeName TEXT,
    drivingDistanceMiles REAL,
    estimatedSavings INTEGER,
    maxStateDocumentationFee INTEGER,
    preselected INTEGER,
    price INTEGER,
    priceExperience INTEGER,
    priceType TEXT,
    quoteId INTEGER NOT NULL,
    sequence INTEGER,
    totalPrice INTEGER,
    totalSavings INTEGER,
    vehicleRowId INTEGER NOT NULL,
    FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
CREATE TABLE Vehicle
(
    _id INTEGER PRIMARY KEY NOT NULL,
    active INTEGER,
    city TEXT,
    downPaymentAmount INTEGER,
    dsaData TEXT,
    dsaSignature TEXT,
    dsaToken TEXT,
    exteriorColorId INTEGER,
    exteriorColorName TEXT,
    exteriorColorRgba TEXT,
    interestRatePercent REAL,
    interiorColorId INTEGER,
    interiorColorName TEXT,
    interiorColorRgba TEXT,
    isInitialized INTEGER NOT NULL,
    isLocked INTEGER NOT NULL,
    isModified INTEGER NOT NULL,
    isRemoved INTEGER NOT NULL,
    makeId INTEGER NOT NULL,
    makeName TEXT,
    modelId INTEGER,
    modelName TEXT,
    modelYear INTEGER,
    numCertificates INTEGER,
    numPayments INTEGER,
    numQuotes INTEGER,
    postalCode TEXT,
    priceExperience INTEGER,
    savingsEstimate INTEGER,
    savingsEstimatePercent REAL,
    sequence INTEGER,
    state TEXT,
    timestamp TEXT,
    totalAverage INTEGER,
    totalEstimate INTEGER,
    totalInvoice INTEGER,
    totalMsrp INTEGER,
    trimId INTEGER NOT NULL,
    trimName TEXT,
    vehicleId TEXT
);
CREATE TABLE Video
(
    _id INTEGER PRIMARY KEY NOT NULL,
    id INTEGER NOT NULL,
    sequence INTEGER NOT NULL,
    youTubeId TEXT,
    dealerRowId INTEGER,
    FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);
