CREATE TABLE Certificate_
(
  _id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  baseMsrp INTEGER,
  baseSavings INTEGER,
  certificateId TEXT NOT NULL,
  dealerId INTEGER NOT NULL,
  dealerTransparencyPledge INTEGER,
  destinationFee INTEGER,
  distanceMiles REAL,
  drivingDistanceMiles REAL,
  estimatedLicensePrice INTEGER,
  estimatedRegistrationPrice INTEGER,
  estimatedSavings INTEGER,
  estimatedTaxPrice INTEGER,
  estimatedTitlePrice INTEGER,
  expirationDate TEXT,
  optionsMsrp INTEGER,
  optionsSavings INTEGER,
  priceBeforeFeesOrAccessories INTEGER,
  priceEmphasis INTEGER NOT NULL,
  priceExperience INTEGER,
  priceType TEXT,
  priceWithFeesAndAccessories INTEGER,
  quoteId TEXT,
  sequence INTEGER,
  specialFeesMsrpTotal INTEGER,
  totalFeesAndAccessories INTEGER,
  totalMsrp INTEGER,
  totalSavings INTEGER,
  syncId TEXT,
  dealerRowId INTEGER,
  vehicleRowId INTEGER,
  FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
  FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);

INSERT INTO Certificate_ (_id, baseMsrp, baseSavings, certificateId, dealerId, destinationFee,
                          distanceMiles, drivingDistanceMiles, estimatedLicensePrice,
                          estimatedLicensePrice, estimatedRegistrationPrice, estimatedSavings,
                          estimatedTaxPrice, estimatedTitlePrice, expirationDate, optionsMsrp,
                          optionsSavings, priceBeforeFeesOrAccessories, priceEmphasis, priceExperience, priceType,
                          quoteId, sequence, syncId, totalMsrp, totalSavings, dealerRowId, vehicleRowId)
  SELECT _id, baseMsrp, baseSavings, certificateId, dealerId, destinationFee,
    distanceMiles, drivingDistanceMiles, estimatedLicensePrice,
    estimatedLicensePrice, estimatedRegistrationPrice, estimatedSavings,
    estimatedTaxPrice, estimatedTitlePrice, expirationDate, optionsMsrp,
    optionsSavings, totalPrice, 0, priceExperience, priceType, quoteId, sequence,
    syncId, totalMsrp, totalSavings, dealerRowId, vehicleRowId
  FROM Certificate;

DROP TABLE Certificate;

ALTER TABLE Certificate_ RENAME TO Certificate;

CREATE TABLE DealerFee
(
  _id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  amount INTEGER,
  feeType INTEGER NOT NULL,
  maxAmount INTEGER,
  name TEXT,
  sequence INTEGER NOT NULL,
  certificateRowId INTEGER,
  offerRowId INTEGER,
  priceCheckRowId INTEGER,
  quoteRowId INTEGER,
  FOREIGN KEY (certificateRowId) REFERENCES Certificate (_id) ON DELETE SET NULL,
  FOREIGN KEY (offerRowId) REFERENCES Offer (_id) ON DELETE SET NULL,
  FOREIGN KEY (priceCheckRowId) REFERENCES PriceCheck (_id) ON DELETE SET NULL,
  FOREIGN KEY (quoteRowId) REFERENCES Quote (_id) ON DELETE SET NULL
);

CREATE TABLE Offer_
(
  _id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  additionalIncentivesTotal INTEGER,
  bannerType INTEGER,
  baseMsrpAmount INTEGER,
  bodyStyle TEXT,
  dealerInstalledOptionsTotal INTEGER,
  dealerTransparencyPledge INTEGER,
  destinationFee INTEGER,
  displayStatus INTEGER,
  driveType TEXT,
  engine TEXT,
  estimatedLicensePrice INTEGER,
  estimatedRegistrationPrice INTEGER,
  estimatedTaxPrice INTEGER,
  estimatedTitlePrice INTEGER,
  expirationDate TEXT,
  exteriorColorName TEXT,
  features TEXT,
  fuel TEXT,
  guaranteedSavings INTEGER,
  imageUrl TEXT,
  interiorColorName TEXT,
  makeId INTEGER,
  makeName TEXT,
  mileage INTEGER,
  modelId INTEGER,
  modelName TEXT,
  msrpTotal INTEGER,
  offerId TEXT NOT NULL,
  oneTimeSavingsPrice INTEGER,
  optionsMsrpTotal INTEGER,
  priceBeforeFeesOrAccessories INTEGER,
  priceEmphasis INTEGER NOT NULL,
  priceWithFeesAndAccessories INTEGER,
  quoteId TEXT,
  savings INTEGER,
  savingsPercent REAL,
  sequence INTEGER,
  specialFeesMsrpTotal INTEGER,
  totalFeesAndAccessories INTEGER,
  trimId INTEGER,
  trimName TEXT,
  vehicleType INTEGER,
  vin TEXT,
  year INTEGER,
  dealerRowId INTEGER,
  FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE
);

INSERT INTO Offer_ (_id, additionalIncentivesTotal, bannerType, baseMsrpAmount, bodyStyle,
                    dealerInstalledOptionsTotal, destinationFee, displayStatus, driveType,
                    engine, estimatedLicensePrice, estimatedRegistrationPrice, estimatedTaxPrice,
                    estimatedTitlePrice, expirationDate, exteriorColorName, features, fuel, guaranteedSavings,
                    imageUrl, interiorColorName, makeId, makeName, mileage, modelId, modelName, msrpTotal, offerId,
                    oneTimeSavingsPrice, optionsMsrpTotal, priceBeforeFeesOrAccessories, priceEmphasis, quoteId,
                    savings, savingsPercent, sequence, trimId, trimName, vehicleType, vin, year, dealerRowId)
  SELECT _id, additionalIncentivesTotal, bannerType, baseMsrpAmount, bodyStyle,
    dealerInstalledOptionsTotal, destinationFee, displayStatus, driveType,
    engine, estimatedLicensePrice, estimatedRegistrationPrice, estimatedTaxPrice,
    estimatedTitlePrice, expirationDate, exteriorColorName, features, fuel, guaranteedSavings,
    imageUrl, interiorColorName, makeId, makeName, mileage, modelId, modelName, msrpTotal, offerId,
    oneTimeSavingsPrice, optionsMsrpTotal, priceTotal, 0, quoteId, savings, savingsPercent, sequence, trimId,
    trimName, vehicleType, vin, year, dealerRowId
  FROM Offer;

DROP TABLE Offer;

ALTER TABLE Offer_ RENAME TO Offer;

DROP TABLE PriceCheck;

CREATE TABLE PriceCheck
(
  _id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  additionalFees INTEGER,
  additionalIncentivesTotal INTEGER,
  baseMsrpAmount INTEGER,
  dealerInstalledOptions TEXT,
  dealerInstalledOptionsTotal INTEGER,
  dealerTransparencyPledge INTEGER,
  destinationFee INTEGER,
  estimatedRegistrationPrice INTEGER,
  estimatedTaxPrice INTEGER,
  expirationDate TEXT,
  exteriorColorName TEXT,
  guaranteedSavings INTEGER,
  id TEXT NOT NULL,
  imageUrl TEXT,
  interiorColorName TEXT,
  license INTEGER,
  makeId INTEGER,
  makeName TEXT,
  modelId INTEGER,
  modelName TEXT,
  msrpTotal INTEGER,
  notes TEXT,
  optionsMsrpTotal INTEGER,
  priceBeforeFeesOrAccessories INTEGER,
  priceEmphasis INTEGER NOT NULL,
  priceWithFees INTEGER,
  savings INTEGER,
  savingsPercent REAL,
  specialFeesMsrpTotal INTEGER,
  taxPercent INTEGER,
  timestamp TEXT NOT NULL,
  title INTEGER,
  totalFees INTEGER,
  trimId INTEGER,
  trimName TEXT,
  vehicleType INTEGER,
  vin TEXT,
  year INTEGER,
  dealerRowId INTEGER,
  FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE
);

CREATE TABLE Quote_
(
  _id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  dealerTransparencyPledge INTEGER,
  distanceMiles REAL,
  drivingDistanceMiles REAL,
  estimatedSavings INTEGER,
  preselected INTEGER,
  price INTEGER,
  priceBeforeFeesOrAccessories INTEGER,
  priceEmphasis INTEGER NOT NULL,
  priceExperience INTEGER,
  priceType TEXT,
  priceWithFeesAndAccessories INTEGER,
  quoteId INTEGER NOT NULL,
  sequence INTEGER,
  totalFeesAndAccessories INTEGER,
  totalSavings INTEGER,
  vehicleRowId INTEGER NOT NULL,
  FOREIGN KEY (vehicleRowId) REFERENCES Vehicle (_id) ON DELETE CASCADE
);

INSERT INTO Quote_ (_id, distanceMiles, drivingDistanceMiles, estimatedSavings, preselected, price,
                    priceBeforeFeesOrAccessories, priceEmphasis, priceExperience, priceType, quoteId,
                    sequence, totalSavings, vehicleRowId)
  SELECT _id, distanceMiles, drivingDistanceMiles, estimatedSavings, preselected, price, totalPrice, 0,
    priceExperience, priceType, quoteId, sequence, totalSavings, vehicleRowId
  FROM Quote;

DROP TABLE Quote;

ALTER TABLE Quote_ RENAME TO Quote;

CREATE TABLE Video_
(
  _id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  sequence INTEGER NOT NULL,
  videoId INTEGER NOT NULL,
  youTubeId TEXT,
  dealerRowId INTEGER,
  FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE
);

INSERT INTO Video_ (sequence, videoId, youTubeId, dealerRowId)
  SELECT sequence, id, youTubeId, dealerRowId
  FROM Video;

DROP TABLE Video;

ALTER TABLE Video_ RENAME TO Video;

CREATE TABLE PriceCheck_
(
  _id INTEGER PRIMARY KEY NOT NULL,
  additionalFees INTEGER,
  additionalIncentivesTotal INTEGER,
  baseMsrpAmount INTEGER,
  dealerInstalledOptions TEXT,
  dealerInstalledOptionsTotal INTEGER,
  dealerTransparencyPledge INTEGER,
  destinationFee INTEGER,
  estimatedRegistrationPrice INTEGER,
  estimatedTaxPrice INTEGER,
  expirationDate TEXT,
  exteriorColorName TEXT,
  guaranteedSavings INTEGER,
  id TEXT NOT NULL,
  imageUrl TEXT,
  interiorColorName TEXT,
  license INTEGER,
  makeId INTEGER,
  makeName TEXT,
  modelId INTEGER,
  modelName TEXT,
  msrpTotal INTEGER,
  notes TEXT,
  optionsMsrpTotal INTEGER,
  priceBeforeFeesOrAccessories INTEGER,
  priceEmphasis INTEGER NOT NULL,
  priceWithFeesAndAccessories INTEGER,
  savings INTEGER,
  savingsPercent REAL,
  specialFeesMsrpTotal INTEGER,
  taxPercent INTEGER,
  timestamp TEXT NOT NULL,
  title INTEGER,
  totalFees INTEGER,
  trimId INTEGER,
  trimName TEXT,
  vehicleType INTEGER,
  vin TEXT,
  year INTEGER,
  dealerRowId INTEGER,
  FOREIGN KEY (dealerRowId) REFERENCES Dealer (_id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED
);

DROP TABLE PriceCheck;

ALTER TABLE PriceCheck_ RENAME TO PriceCheck;
