
namespace java com.truecar.thrift.type
namespace cocoa TCThrift

/**
 * Fixed point integer representation of a geographic dimension (either
 * longitude or latitude.
 */
typedef i32 GeoValue

/**
 * Multiplier for scaling of geographic dimension values: multiplying a
 * floating point value by this number yields an appropriately scaled fixed
 * point value; dividing by this value will yield an appropriately scaled
 * floating point representation.
 */
const i32 GEO_VALUE_MULTIPLIER = 1000000


/**
 * Representation of a geographical point.
 */
struct GeoPoint {
	/**
	 * Latitude expressed in degrees, scaled using the pre-defined multipler.
	 * Positive latitudes denote the northern hemisphere.
	 */
	1:required GeoValue latitude,
	
	/**
	 * Longitude expressed in degrees, scaled using the pre-defined multipler.
	 * Positive longitudes denote locations east of the Prime Meridian.
	 */
	2:required GeoValue longitude
}

