include "../common/Monetary.thrift"
include "../common/Numeric.thrift"
include "Option.thrift"
include "Incentive.thrift"
include "OfferVehicleType.thrift"
include "OfferAvailability.thrift"
include "OfferDisplayStatus.thrift"
include "OfferBannerType.thrift"
include "../common/Temporal.thrift"
include "../common/DealerFeeOrAccessory.thrift"
include "../common/PriceEmphasis.thrift"

namespace cocoa TCThriftConsumerApp_
namespace java com.truecar.mobile.thrift.consumerapp

/**
 *	Offer.
 */
struct Offer
{
	/**
	 *	Offer ID.
	 */
	1: required string offerId,
	
	/**
	 *	Vehicle identification number.
	 */
	2: optional string vin,
	
	/**
	 *	Make ID.
	 */
	3: optional i64 makeId,
	
	/**
	 *	Make name.
	 */
	4: optional string makeName,
	
	/**
	 *	Year.
	 */
	5: optional i16 year,
	
	/**
	 *	Model ID.
	 */
	6: optional i64 modelId,
	
	/**
	 *	Model name.
	 */
	7: optional string modelName,
	
	/**
	 *	Trim ID.
	 */
	8: optional i64 trimId,
	
	/**
	 *	Trim name.
	 */
	9: optional string trimName,
	
	/**
	 *	Total price before fees.
	 */
	10: optional Monetary.UsdCents priceBeforeFeesOrAccessories,
	
	/**
	 *	Savings off MSRP, excluding incentives.
	 */
	11: optional Monetary.UsdCents savings,
	
	/**
	 *	Savings percentage off MSRP.
	 */
	12: optional double savingsPercent,
	
	/**
	 *	MSRP.
	 */
	13: optional Monetary.UsdCents msrpTotal,
	
	/**
	 *	Base price.
	 */
	14: optional Monetary.UsdCents baseMsrpAmount,
	
	/**
	 *	Total price of dealer installed options.
	 */
	15: optional Monetary.UsdCents dealerInstalledOptionsTotal,

	/**
	 *	Destination fee.
	 */
	16: optional Monetary.UsdCents destinationFee,

	/**
	 *	Documentation fee.
	 */
	17: optional Monetary.UsdCents deprecatedDocumentationFee,

    /**
     *	Documentation fee name.
     */
    18: optional string deprecatedDocumentationFeeName,

	/**
	 *	Total MSRP of options.
	 */
	19: optional Monetary.UsdCents optionsMsrpTotal,

	/**
	 *	Total amount of all incentives that are not included in the guaranteed savings.
	 */
	20: optional Monetary.UsdCents additionalIncentivesTotal,

	/**
	 *	Savings off MSRP, including incentives EXCEPT for the ones that are NOT included in guaranteed savings.
	 */
	21: optional Monetary.UsdCents guaranteedSavings,

	/**
	 *	Complete options information.
	 */
	22: optional list<Option.Option> options,

	/**
	 *	Complete incentives information.
	 */
	23: optional list<Incentive.Incentive> incentives,
	
	/**
	 *	Contact IDs.
	 *
	 *	This is a reference to the dealer contact or contacts that have been assigned to the user for this certificate.
	 *	The IDs must exist in the contacts for the dealer for this offer.
	 */
	24: optional list<i64> contactIds,
	
	/**
	 * Expiration date.
	 */
	25: optional Temporal.DateIsoString expirationDate,
    
    26: optional OfferVehicleType.OfferVehicleType offerVehicleType,
 
    28: optional string imageUrl,
    
    29: optional Monetary.UsdCents deprecatedMaxStateDocumentationFee,
    
    30: optional OfferDisplayStatus.OfferDisplayStatus offerDisplayStatus,  
    
    31: optional i32 mileage,
    
    32: optional string bodyStyle,
    
    33: optional string driveType,
    
    34: optional string fuel,
    
    35: optional string features,
    
    36: optional string quoteId,
    
    37: optional string interiorColorName,
    
    38: optional string exteriorColorName,
    
    /**
     * Deprecated in MSP 6.0.0+.  Use "specialFeesInvoiceTotal" instead.
     */
    39: optional Monetary.UsdCents deprecatedRegionalFeesPrice,
    
    40: optional Monetary.UsdCents oneTimeSavingsPrice,
    
    41: optional Monetary.UsdCents estimatedTaxPrice,
    
    42: optional Monetary.UsdCents estimatedTitlePrice,
    
    43: optional Monetary.UsdCents estimatedLicensePrice,
    
    44: optional Monetary.UsdCents estimatedRegistrationPrice,
    
    45: optional string engine,

    46: optional OfferBannerType.OfferBannerType offerBannerType,
    
    /**
     *	List of dealer fees.
     */
    47: optional list<DealerFeeOrAccessory.DealerFeeOrAccessory> dealerFeesAndAccessories,
    
    /**
     * Dealer transparency pledge.
     */
    48: optional bool dealerTransparencyPledge,
    
    /**
     * This value indicates the price to emphasize on. e.g. price, price + dealer installed options + doc fee etc.
     *
     */
    49: optional PriceEmphasis.PriceEmphasis priceEmphasis,
    
    /**
	 *	Price total with fees.
	 */
	50: optional Monetary.UsdCents priceWithFeesAndAccessories,
	
	/**
	 * Fees total.
	 */
	51: optional Monetary.UsdCents totalFeesAndAccessories,
	
	/**
     * Whether or not the transparency pledge badge should be shown (note this is different than the dealerTransparencyPledge flag).
     */
    52: optional bool showDealerTransparencyPledge,	 
    
    /**
     * Regional fees value (should be specialFeesMsrpTotal from platform APIs)
     */
    53: optional Monetary.UsdCents specialFeesMsrpTotal,
}
