include "TCThriftDealer.thrift"
include "Charts.thrift"
include "ConsumerApp/OptionState.thrift"
include "ConsumerApp/PriceExperience.thrift"
include "ConsumerApp/IncentiveType.thrift"

namespace cocoa TCThrift
namespace java com.truecar.mobile.thriftApi

//  Note: All prices are 32-bit integers in cents, allowing values up to $21,474,836.48. This range easily covers the
//  current prices of new vehicles available through TrueCar.

enum Locality
{
    LOCAL,
    REGIONAL,
    NATIONAL,
}

enum Comparison
{
    BELOW,
    EQUAL,
    ABOVE,
}

struct VehicleCurveData
{
                                                //  NCCD (NewCarCurveLocalityData) Field    Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional i32 goodPriceCents,                      //  goodPrice                               in cents
    2:optional i32 greatPriceCents,                     //  greatPrice                              in cents
    3:optional i32 purchaseCount,                       //  purchaseCount
    4:optional i32 aboveMarketPriceCents,               //  aboveMarketPrice                        in cents
    5:optional i32 histMinimumPriceCents,               //  histMinimum                             in cents
    6:optional i32 histMaximumPriceCents,               //  histMaximum                             in cents
    7:optional double deviation,                        //  deviation
    8:optional double invoicePercent,                   //  prices[INVOICE].percentage
    9:optional i32 invoicePriceCents,                   //  prices[INVOICE].price                   in cents
    10:optional double msrpPercent,                     //  prices[MSRP].percentage
    11:optional i32 msrpPriceCents,                     //  prices[MSRP].price                      in cents
    12:optional double averagePercent,                  //  prices[AVERAGE].percentage
    13:optional i32 averagePriceCents,                  //  prices[AVERAGE].price                   in cents
    14:optional double dealerPercent,                   //  prices[DEALER].percentage
    15:optional i32 dealerPriceCents,                   //  prices[DEALER].price                    in cents
    16:optional bool isCurveAvailable,                  //  curveAvailable
    17:optional bool isBasicPriceReport,                //  basicPriceReport
    18:optional i32 averageBasePriceCents,              //  baseAveragePaid                         in cents
    19:optional i32 averageOptionsPriceCents,           //  optionsAveragePaid                      in cents
    20:optional i32 goodOffsetCents,                    //  goodPriceOffset                         in cents
    21:optional i32 greatOffsetCents,                   //  greatPriceOffset                        in cents
    22:optional i32 dealerOffsetCents,                  //  dealerCostOffset                        in cents
    23:optional i32 aboveMarketOffsetCents,             //  aboveMarketOffset                       in cents
    24:optional i32 msrpOffsetCents,                    //  msrpOffset                              in cents
    25:optional i32 averageGoodOffsetCents,             //  goodPriceAverageOffset                  in cents
    26:optional i32 averageGreatOffsetCents,            //  greatPriceAverageOffset                 in cents
    27:optional double modelCoefficient,                //  modelCoefficient
    28:optional i32 histMinimumOffsetCents,             //  offsetHistMinimum                       in cents
    29:optional i32 histMaximumOffsetCents,             //  offsetHistMaximum                       in cents
    30:optional double calloutPercent,                  //  curveCallout.percentage
    31:optional string calloutType,                     //  curveCallout.priceType,
    32:optional i32 averageSavedPriceCents,             //  averageSaved                            in cents
    33:optional double averageSavedPercent,             //  averageSavedPercent
}

struct VehicleDealContact
{
    1:required i32 id,
    2:optional string name,
    3:optional string title,
    4:optional string email,
    5:optional string quote,
    6:optional string imageUrl,
}

struct VehicleDealPerk
{
    1:required i64 id,
    2:optional i16 iconType,
    3:optional string title,
    4:optional string desc,
}

struct VehicleDealPhoto
{
    1:required i32 id,
    2:optional string imageUrl,
}

struct VehicleDealVideo
{
    1:required i32 id,
    2:optional string youTubeId,
}

struct VehiclePricing
{
                                                //  NCCD (PricingGroup) Field               Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional i32 priceTotalCents,                     //  priceTotal                              in cents
    2:optional i32 savingsCents,                        //  savings                                 in cents
    3:optional double savingsPercent,                   //  savingsPercent
    4:optional i32 msrpTotalCents,                      //  msrpTotal                               in cents
    5:optional string type,                             //  type
    6:optional i32 baseCents,                           //  base                                    in cents
}

struct VehicleSpecialFee
{
                                                //  NCCD (DealershipSpecialFee) Field       Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional i32 invoiceFlatFeeCents,                 //  invoiceFlatFee                          in cents
    2:optional double pricePercent,                     //  pricePercent
    3:optional i32 msrpFlatFeeCents,                    //  msrpFeeFlat                             in cents
    4:optional string baseFeeType,                      //  baseFeeType
    5:optional i16 includeFreightFlag,                  //  includeFreightFlag
    6:optional string optionsType,                      //  optionsType
}

struct VehicleQuote
{
                                                //  NCCD (NewCarCurveDealership) Field      Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional TCThriftDealer.Dealer dealer,            //  n/a
    2:optional double distanceMiles,                    //  distanceFromSearchPostalCode
    3:optional i32 invoiceOffsetCents,                  //  dealerOffset                            in cents
    4:optional bool isLeadSubmitted,                    //  n/a
    5:optional string timestamp,                        //  n/a                                     ISO 8601 UTC Date/Time (####-##-##T##:##:##Z); not set when isLeadSubmitted = false
    6:optional i32 documentationFeeCents,               //  n/a                                     in cents
    7:optional i32 maxStateDocumentationFeeCents,       //  n/a                                     in cents
    8:optional double drivingDistanceMiles,             //  n/a
    9:optional i32 msrpOffsetCents,                     //  priceMsrpOffset                         in cents
    10:optional i32 priceCents,                         //  price                                   in cents
    11:optional list<VehicleSpecialFee> specialFees,    //  specialFees
    12:optional string priceType,                       //  priceType
    13:optional bool isPreselected,                     //  preselected
    14:optional double priceMsrpOffsetPercent,          //  priceMsrpOffsetPercentage
    15:optional i32 specialFeesInvoiceTotalCents,       //  specialFeesInvoiceTotal                 in cents
    16:optional i32 pricingMessageId,                   //  pricingMessageId
    17:optional i32 estimatedSavingsCents,              //  estimatedSavings                        in cents
    18:optional double estimatedSavingsPercent,         //  percentEstimatedSavingsFromMsrp
    19:optional i32 customerProgramIncentivesCents,     //  customerAndProgramIncentives            in cents
    20:optional i32 customerIncentivesCents,            //  customerIncentives                      in cents
    21:optional i32 dealerIncentivesCents,              //  dealershipIncentives                    in cents
    22:optional bool isLowestPrice,                     //  lowestPrice
    23:optional VehiclePricing minimumGuaranteedPricing,//  minimumGuaranteedPricing
    24:optional double localAxisPercent,                //  localAxisPercentage
    25:optional double regionalAxisPercent,             //  regionalAxisPercentage
    26:optional double nationalAxisPercent,             //  nationalAxisPercentage
    27:optional string certificateId,                   //  n/a
    28:optional string certificateUrl,                  //  n/a
    29:optional list<VehicleDealContact> contacts,
    30:optional list<VehicleDealPhoto> photos,
    31:optional list<VehicleDealVideo> videos,
    32:optional list<VehicleDealPerk> perks,
	33:required i64 id,                                 //  dealershipId for submissions.
	34:optional VehiclePricing pricing,                 //  pricing
    
 
    35:optional i32 baseMsrpCents,                                          //  Base MSRP. Does not include options or fees.
    36:optional i32 baseSavingsCents,                                        //  Base savings from base MSRP. Includes dealer offset, manufacturer-to-dealer incentives, and pre-selected incentives.
    37:optional double baseSavingsPercent,                                   //  Base savings percent from base MSRP. baseSavingsPercent = baseSavings / baseMsrp.
    38:optional i32 destinationFeeCents,                                     //  Destination fee. Also known as freight fee.
    39:optional i32 optionsMsrpCents,                                        //  Options MSRP. Total MSRP of selected options.
    40:optional i32 optionsSavingsCents,                                     //  Options savings from options MSRP.
    41:optional PriceExperience.PriceExperience priceExperience,             //  Price experience.
    42:optional i32 regionalAdFeeCents,                                      //  Regional ad fee. Also known as special fees, including option based special fees.
    43:optional i32 totalMsrpCents,                                          //  Total MSRP. Includes options and fees.
    44:optional i32 totalPriceCents,                                         //  Total price. If nil, dealer will provide price. For target price experience, should be equal to vehicle.totalEstimate.
    45:optional i32 totalSavingsCents,                                       //  Total savings from MSRP. totalSavings = totalMsrp - totalPrice. If totalPrice > totalMsrp, totalSavings will be negative.
    46:optional double totalSavingsPercent,                                  //  Total savings percent from MSRP. totalSavingsPercent = totalSavings / totalMsrp.
    47:optional i32 additionalIncentivesTotal,                               //  sum of selected incentives, excluding manufacturer to dealer and pre-selected
    48:optional string documentationFeeName,                                 //  name of documentation fee
    
    49:optional i32 priceTotalPlusDocumentationFee,
}

struct VehicleHistogramBucket
{
                                                //  NCCD (Bucket) Field                     Notes
                                                //  --------------------------------------- ----------------------------------------
    1:required i32 transactionCount,                    //  transactionCount
    2:required i32 minimumCents,                        //  minimum                                 in cents
    3:required i32 maximumCents,                        //  maximum                                 in cents
}

struct VehicleIncentive
{
                                                //  NCCD (n/a) Field                        Notes
                                                //  --------------------------------------- ----------------------------------------
    1:required i64 id,                                  //  n/a
    2:optional string name,                             //  n/a
    3:optional string desc,                             //  n/a
    4:optional string startDate,                        //  n/a                                     ISO 8601 Date (####-##-##)
    5:optional string endDate,                          //  n/a                                     ISO 8601 Date (####-##-##)
    6:optional i32 amountCents,                         //  n/a                                     in cents
    7:optional bool preselected,
    8:optional IncentiveType.IncentiveType incentiveType,
    9:optional i64 dealershipId,                        //  n/a
}

struct VehicleOption
{
                                                //  NCCD (n/a) Field                        Notes
                                                //  --------------------------------------- ----------------------------------------
    1:required i64 id,                                  //  n/a
    2:optional string name,                             //  n/a
    3:optional string desc,                             //  n/a
    4:optional string optionCategoryName,               //  n/a
    5:optional i32 invoiceCents,                        //  n/a                                     in cents
    6:optional i32 msrpCents,                           //  n/a                                     in cents
    7:required i16 trimOptionId,                        //  n/a
    8:optional OptionState.OptionState optionState,                 //  n/a
}

struct VehicleConfiguration
{
                                                //  NCCD (NewCarCurveData) Field            Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional i64 makeId,                              //  vehicle.makeId                          Zag / TrueCar ID
    2:optional string makeName,                         //  vehicle.makeName
    3:optional i64 modelId,                             //  vehicle.modelId                         Zag / TrueCar ID
    4:optional string modelName,                        //  vehicle.modelName
    5:optional i32 modelYear,                           //  vehicle.modelYear
    6:required i64 trimId,                              //  vehicle.trimId                          Zag / TrueCar ID
    7:optional string trimName,                         //  vehicle.trimName
    8:optional i64 exteriorColorId,                     //  vehicle.exteriorColorId
    9:optional string exteriorColorName,                //  n/a
    10:optional string exteriorColorRgba,               //  n/a                                     RGB + alpha in hex
    11:optional i64 interiorColorId,                    //  n/a
    12:optional string interiorColorName,               //  n/a
	13:optional string interiorColorRgba,               //  n/a                                     RGB + alpha in hex
    14:optional list<VehicleOption> options,            //  n/a                                     selected options
    15:optional list<VehicleIncentive> incentives,      //  n/a                                     selected incentives
    16:optional string postalCode,                      //  postalCode                              search ZIP Code
    17:optional string city,
    18:optional string state,
}

struct VehiclePriceReport
{
                                                //  NCCD (NewCarCurveData) Field            Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional i32 trimInvoiceCents,                    //  baseInvoiceAmount                       in cents
    2:optional i32 trimMsrpCents,                       //  baseMsrpAmount                          in cents
    3:optional i32 totalInvoiceCents,                   //  n/a                                     in cents, including options and incentives
    4:optional i32 totalMsrpCents,                      //  n/a                                     in cents, including options and incentives
    5:optional VehicleCurveData localCurveData,         //  local
    6:optional VehicleCurveData regionalCurveData,      //  regional
    7:optional VehicleCurveData nationalCurveData,      //  national
    8:optional i32 freightFeeCents,                     //  freightFee                              in cents
    9:optional i32 optionsMsrpCents,                    //  optionsMsrpAmount                       in cents; options.@sum.msrp
    10:optional i32 customerIncentivesCents,            //  customerIncentiveAmount                 in cents; incentives.@sum.amount
                                                //  priceExperience
    11:optional PriceExperience.PriceExperience priceExperience = PriceExperience.PriceExperience.RESTRICTED,
    12:optional bool isInvoiceShown,                    //  showInvoice
    13:optional i32 totalTargetCents,                   //  targetPrice                             in cents
    14:optional i32 targetMsrpOffsetCents,              //  targetMsrpOffset                        in cents
    15:optional i32 holdbackAmountCents,                //  holdbackAmount                          in cents
    16:optional bool isAbpActive,                       //  abpActive
    17:optional bool isTcprAvailable,                   //  tcprAvailable
    18:optional i64 abpActiveTrimId,                    //  abpActiveTrimId
    19:optional i32 abpActiveModelYear,                 //  abpActiveYear
    20:optional i32 targetTotalOffsetCents,             //  targetTotalOffset                       in cents
    21:optional bool isLeadGenEligible,                 //  leadGenEligible
    22:optional i32 optionsInvoiceCents,                //  optionsInvoiceAmount                    in cents; options.@sum.invoice
    23:optional i32 trimTargetCents,                    //  targetBaseAmount                        in cents
    24:optional i32 customerProgramIncentivesCents,     //  customerAndProgramIncentives            in cents
    25:optional i32 dealerIncentivesCents,              //  dealershipIncentives                    in cents
    26:optional i32 specialFeesInvoiceCents,            //  specialFeesInvoiceTotal                 in cents
    27:optional i32 specialFeesMsrpCents,               //  specialFeesMsrpTotal                    in cents
    28:optional i32 trimConfiguratorCents,              //  configuratorBase                        in cents
    29:optional i32 totalConfiguratorCents,             //  configuratorTotal                       in cents
    30:optional i32 configuratorMsrpSavingsCents,       //  configuratorSavingsFromMsrp             in cents
    31:optional double configuratorMsrpSavingsPercent,  //  configuratorSavingsFromMsrpPercent
    32:optional Locality locality,                      //  histogram.locality
    33:optional list<VehicleHistogramBucket> buckets,   //  histogram.buckets
    34:optional i32 transactionCount,                   //  histogram.totalTransactionCount
    35:optional i16 historicalDays,                     //  histogram.historicalDays
    36:optional VehiclePricing historicalAveragePricing,//  historicalAveragePricing
    37:optional VehiclePricing targetPricing,           //  targetPricing
    38:optional i32 trimDealerCostCents,                //  baseDealerCost                          in cents
    39:optional VehiclePricing configuratorPricing,     //  configuratorPricing
                                                //  configuredHistoricalAveragePricing
    40:optional VehiclePricing configuredHistoricalAveragePricing,
	41:optional i32 totalEstimateCents,
	42:optional i32 savingsEstimateCents,
	43:optional double savingsEstimatePercent,
	44:optional string dsaToken,                        // bphToken
	45:optional string dsaSignature,                    // sk
    46:optional string dsaData,                         // dd 
	47:optional i32 totalAverageCents,
    
    48:optional Charts.ChartSet localChartSet, 
    49:optional Charts.ChartSet nationalChartSet,
    
    50:optional string abTestsRun,                      // TC-Track formatted string of all AB-tests that affected generation of the report.
}

struct VehiclePortfolio
{
                                                //  NCCD (NewCarCurveData) Field            Notes
                                                //  --------------------------------------- ----------------------------------------
    1:optional string id,                               //  n/a                                     empty for new or detached vehicle
	2:optional VehicleConfiguration configuration,		//	n/a										choices made by user
	3:optional VehiclePriceReport priceReport			//	n/a										pricing supplied by server
	4:optional list<VehicleQuote> quotes				//	n/a										quotes supplied by server
    5:optional string timestamp,                        //  n/a                                     ISO 8601 UTC Date/Time (####-##-##T##:##:##Z)
}
