include "../common/Monetary.thrift"
include "PriceExperience.thrift"
include "../common/Temporal.thrift"
include "../common/DealerFeeOrAccessory.thrift"
include "../common/PriceEmphasis.thrift"

namespace cocoa TCThriftConsumerApp_
namespace java com.truecar.mobile.thrift.consumerapp

/**
 *	Certificate.
 *
 *	A certificate is created when leads are submitted on a saved vehicle. It represents the relationship between a user
 *	and a dealer for a particular saved vehicle.
 *
 *	Note: in the prior version of the API, a VehicleQuote represented both a quote and a certificate as now defined. The
 *	difference was in the presence of the dealer details and the isLeadSubmitted flag.
 */
struct Certificate
{
	/**
	 *	Certificate ID.
	 */
	1: required string certificateId,
	
	/**
	 *	Dealer ID.
	 *
	 *	This is a reference to the dealer for this certificate. The dealer is usually returned in the same response from
	 *	the server that contains this certificate.
	 */
	2: required i64 dealerId,
	
	/**
	 *	Contact IDs.
	 *
	 *	This is a reference to the dealer contact or contacts that have been assigned to the user for this certificate.
	 *	The IDs must exist in the contacts for the referenced dealer.
	 */
	3: optional list<i64> contactIds,

	/**
	 *	Distance from search ZIP Code in miles.
	 */
	4: optional double distanceMiles,
	
	/**
	 *	Driving distance from search ZIP Code in miles.
	 */
	5: optional double drivingDistanceMiles,
	
	/**
	 *	Price experience.
	 */
	6: optional PriceExperience.PriceExperience priceExperience,
	
	/**
	 *	Price type.
	 */
	7: optional string priceType,
	
	/**
	 *	Base MSRP.
	 *
	 *	Does not include options or fees.
	 */
	8: optional Monetary.UsdCents baseMsrp,
	
	/**
	 *	Base savings from base MSRP.
	 *
	 *	Includes dealer offset, manufacturer-to-dealer incentives and pre-selected incentives.
	 */
	9: optional Monetary.UsdCents baseSavings,
	
	/**
	 *	Destination fee.
	 *
	 *	Also known as freight fee.
	 */
	10: optional Monetary.UsdCents destinationFee,
	
	/**
	 *	Options MSRP.
	 *
	 *	Total MSRP of selected options.
	 */
	11: optional Monetary.UsdCents optionsMsrp,
	
	/**
	 *	Options savings from options MSRP.
	 */
	12: optional Monetary.UsdCents optionsSavings,
	
	/**
	 *	Total MSRP.
	 *
	 *	Includes options and fees.
	 */
	13: optional Monetary.UsdCents totalMsrp,

	/**
	 *	Total price before fees.
	 *
	 *	If not set, dealer will provide price. For target price experience, should be equal to vehicle.totalEstimate.
	 */
	14: optional Monetary.UsdCents priceBeforeFeesOrAccessories,

	/**
	 *	Price.
	 *
	 *	This may be the same as totalPrice. We only use this field in analytics and should check MSP implementation to
	 *	see if it can be removed.
	 */
	15: optional Monetary.UsdCents price,
	
	/**
	 *	Total savings from MSRP.
	 *
	 *	totalSavings = totalMsrp - totalPrice. If totalPrice > totalMsrp, totalSavings will be negative.
	 */
	16: optional Monetary.UsdCents totalSavings,

	/**
	 *	Estimated savings.
	 *
	 *	This may be the same as totalSavings. We only use this field in analytics and should check MSP implementation to
	 *	see if it can be removed.
	 */
	17: optional Monetary.UsdCents estimatedSavings,

	/**
	 *	Documentation fee.
	 */
	18: optional Monetary.UsdCents deprecatedDocumentationFee,
	
	/**
	 *	Maximum allowed documentation fee for state.
	 */
	19: optional Monetary.UsdCents deprecatedMaxStateDocumentationFee,
	
	/**
	 *	Documentation fee name.
	 */
	20: optional string deprecatedDocumentationFeeName,
	
	/**
	 *	(Deprecated in MSP 6.0.0+) Regional fee.  Use "specialFeesMsrpTotal" instead.
	 */
	21: optional Monetary.UsdCents deprecatedSpecialFeesInvoiceTotal,
	
	/**
	 * Expiration date. 
	 */
	22: optional Temporal.DateIsoString expirationDate,
    
    23: optional string quoteId,
    
    24: optional Monetary.UsdCents estimatedTaxPrice,
    
    25: optional Monetary.UsdCents estimatedTitlePrice,
    
    26: optional Monetary.UsdCents estimatedLicensePrice,
    
    27: optional Monetary.UsdCents estimatedRegistrationPrice,
    
    /**
     *	List of dealer fees.
     */
    28: optional list<DealerFeeOrAccessory.DealerFeeOrAccessory> dealerFeesAndAccessories,

	/**
     * Dealer transparency pledge.
     */
    29: optional bool dealerTransparencyPledge,
    
    /**
     * This value indicates the price to emphasize on. e.g. price, price + dealer installed options + doc fee etc.
     *
     */
    30: optional PriceEmphasis.PriceEmphasis priceEmphasis,
    
	/**
	 *	Price total with fees.
	 */
	31: optional Monetary.UsdCents priceWithFeesAndAccessories,   
	
	/**
	 * Fees total.
	 */
	32: optional Monetary.UsdCents totalFeesAndAccessories,
	
	/**
     * Whether or not the transparency pledge badge should be shown (note this is different than the dealerTransparencyPledge flag).
     */
    33: optional bool showDealerTransparencyPledge,
    
    /**
     * Regional fees value (should be specialFeesMsrpTotal from platform APIs)
     */
    34: optional Monetary.UsdCents specialFeesMsrpTotal,
}
