include "../common/Monetary.thrift"
include "Certificate.thrift"
include "ChartSet.thrift"
include "Incentive.thrift"
include "Option.thrift"
include "PriceExperience.thrift"
include "Quote.thrift"

namespace cocoa TCThriftConsumerApp_
namespace java com.truecar.mobile.thrift.consumerapp

/**
 *	Saved vehicle.
 *
 *	The saved vehicle includes vehicle configuration, price report, curve, histogram, quotes, and certificates. In a
 *	response from the server, it should be as completely filled as possible. In an update request from the app, however,
 *	only the required attributes, the required attributes from the options and incentives lists, postalCode, and
 *	(sometimes) the vehicle ID will be set. These are essentially the only changes to a saved vehicle that the user can
 *	make.
 */
struct Vehicle
{
	/**
	 *	Vehicle ID.
	 *
	 *	Not sent to server for newly added vehicles. In this case, the server will create a new vehicleId value and
	 *	return it to the app.
	 */
	1: optional string vehicleId,
	
	/**
	 *	Make ID.
	 *
	 *	TrueCar / Zag ID.
	 */
	2: required i64 makeId,
	
	/**
	 *	Make name.
	 */
	3: optional string makeName,
	
	/**
	 *	Model ID.
	 *
	 *	TrueCar / Zag ID.
	 */
	4: required i64 modelId,
	
	/**
	 *	Model name.
	 */
	5: optional string modelName,
	
	/**
	 *	Model year.
	 */
	6: optional i32 modelYear,
	
	/**
	 *	Trim ID.
	 *
	 *	TrueCar / Zag ID.
	 */
	7: required i64 trimId,
	
	/**
	 *	Trim name.
	 */
	8: optional string trimName,
	
	/**
	 *	Exterior color ID.
	 */
	9: optional i64 exteriorColorId,
	
	/**
	 *	Exterior color name.
	 */
	10: optional string exteriorColorName,
	
	/**
	 *	Exterior color RGBA value.
	 *
	 *	RGB + alpha in hex.
	 */
	11: optional string exteriorColorRgba,
	
	/**
	 *	Interior color ID.
	 */
	12: optional i64 interiorColorId,
	
	/**
	 *	Interior color name.
	 */
	13: optional string interiorColorName,
	
	/**
	 *	Interior color RGBA value.
	 *
	 *	RGB + alpha in hex.
	 */
	14: optional string interiorColorRgba,
	
	/**
	 *	Selected options.
	 */
	15: optional list<Option.Option> options,
	
	/**
	 * 	Selected incentives.
	 */
	16: optional list<Incentive.Incentive> incentives,
	
	/**
	 *	Search ZIP Code.
	 */
	17: optional string postalCode,
	
	/**
	 *	Search city.
	 *
	 *	City is provided by server, if possible, by looking up the ZIP Code.
	 */
	18: optional string city,

	/**
	 *	Search state.
	 *
	 *	State is provided by server, if possible, by looking up the ZIP Code.
	 */
	19: optional string state,
	
	/**
	 *	Price experience.
	 */
	20: optional PriceExperience.PriceExperience priceExperience,

	/**
	 *	Total invoice price, including options and incentives.
	 */
	21: optional Monetary.UsdCents totalInvoice,
	
	/**
	 *	Total MSRP, including options and incentives.
	 */
	22: optional Monetary.UsdCents totalMsrp,

	/**
	 *	Total average price, including options and incentives.
	 */
	23: optional Monetary.UsdCents totalAverage,

	/**
	 *	Total estimated price.
	 *
	 *	The labeling of this price is determined by the price experience. It might be a target price, or it might be the
	 *	best price among the upfront prices available.
	 */
	24: optional Monetary.UsdCents totalEstimate,
	
	/**
	 *	Estimated savings off MSRP.
	 */
	25: optional Monetary.UsdCents savingsEstimate,
	
	/**
	 *	Estimated savings off MSRP as percentage.
	 */
	26: optional double savingsEstimatePercent,
	
	/**
	 *	DSA token.
	 *
	 *	Opaque value to be sent to server when leads are submitted.
	 */
	27: optional string dsaToken,
	
	/**
	 *	DSA signature.
	 *
	 *	Opaque value to be sent to TCTrack as dsa_sk parameter.
	 */
	28: optional string dsaSignature,
	
	/**
	 *	DSA data.
	 *
	 *	Opaque value to be sent to TCTrack as dsa_dd parameter.
	 */
	29: optional string dsaData,
	
    /**
     *	Active flag. Vehicles flagged as inactive should be removed local data storage
     */
    30:optional bool active,

	/**
	 *	Local charts.
	 */
	31: optional ChartSet.ChartSet localChartSet,
	
	/**
	 *	National charts.
	 */
	32: optional ChartSet.ChartSet nationalChartSet,

	/**
	 *	Quotes.
	 *
	 *	Quotes become certificates when leads are submitted.
	 */
	33: optional list<Quote.Quote> quotes,
	
	/**
	 *	Certificates.
	 */
	34: optional list<Certificate.Certificate> certificates,
}
