include "TCThriftVehicle.thrift"

namespace cocoa TCThrift
namespace java com.truecar.mobile.thriftApi

//
//	BaseURL
//
//	The base URL for this API is https://{host}/api/{version}.
//	The base path is thus /api/{version}.
//

//
//	SubmitLeads API Endpoint
//
//	This API endpoint is used to submit leads for a vehicle. Submitting a lead will cause the returned VehicleQuote
//	object in the vehicle portfolio to contain Dealer information. This API has no synchronization aspects; the user
//	expects that a failure to connect would not submit the leads. In the spirit of fat APIs, this API returns the
//	complete affected vehicle; this time with additional information on the quotes for which the leads were submitted,
//	such as dealer name and contact information.
//
//	URL: {baseUrl}/submit-leads/user/{userHandle}
//
//	Request:
//		POST {basePath}/submit-leads/user/{userHandle} HTTP/1.1
//		Host: {host}
//		Content-Type: application/x-thrift
//		Content-Length: {length}
//		Accept: application/x-thrift
//		X-TrueCar-Token: {secureToken}
//
//		{SubmitLeadsRequest}
//
//	Response (success):
//		HTTP/1.1 200 OK
//		Content-Type: application/x-thrift
//		Content-Length: {length}
//
//		{SubmitLeadsResponse}
//
//	Response (error):
//		HTTP/1.1 {non200Status}
//		Content-Type: application/x-thrift
//		Content-Length: {length}
//
//		{Exception}
//
//	Potential Error Codes:
//		TokenInvalid
//		TokenExpired
//		UserHandleInvalid
//		VehiclePortfolioNotFound
//		DealNotFound
//		
struct SubmitLeadsRequest
{
	1:required string vehiclePortfolioId,
	2:required list<i64> quoteIds,
	3:required string bphToken,
}

struct SubmitLeadsResponse
{
	1:required TCThriftVehicle.VehiclePortfolio vehiclePortfolio,
	2:optional bool firstLeadSubmission,  //whether or not this submission represents the first ever lead submission for the user submitting.  Used for analytics.
}
