/*
 * This file provides definition for common error codes and an associated
 * exception.
 */
 
namespace java com.truecar.thrift.exception
namespace cocoa TCThrift

/**
 * Error codes.  The integer values for error codes are a logical composite of
 * a standard HTTP status code and a TrueCar-specific value.
 */
enum ErrorCode {
	//	HTTP status: 400 Bad Request
	ADDRESS_INVALID = 400001,
	APP_ID_INVALID,
	APP_VERSION_INVALID,
	CITY_INVALID,
	DEAL_ID_INVALID,
	EMAIL_INVALID,
	FIRST_NAME_INVALID,
	LAST_NAME_INVALID,
	LATITUDE_INVALID,
	LONGITUDE_INVALID,
	MAKE_ID_INVALID,
	MODEL_ID_INVALID,
	PAG_ID_INVALID,
	PASSWORD_INVALID,
	PHONE_INVALID,
	POSTAL_CODE_INVALID,
	SEARCH_POSTAL_CODE_INVALID,
	STATE_INVALID,
	TRIM_ID_INVALID,
	TOKEN_INVALID,
	USER_HANDLE_INVALID,
	USER_NAME_INVALID,
	VEHICLE_PORTFOLIO_ID_INVALID,
	VIN_INVALID,

	//	HTTP status: 401 Unauthorized
	AUTHENTICATION_FAILED = 401001,
	TOKEN_EXPIRED,
	
	//	HTTP status: 404 Not Found
	APP_NOT_FOUND = 404001,
	APP_VERSION_NOT_FOUND,
	DEAL_NOT_FOUND,
	MAKE_ID_NOT_FOUND,
	MODEL_ID_NOT_FOUND,
	PAG_ID_NOT_FOUND,
	POSTAL_CODE_NOT_FOUND,
	TRIM_ID_NOT_FOUND,
	USER_NOT_FOUND,
	VEHICLE_PORTFOLIO_NOT_FOUND,
	
	//	HTTP status: 409 Conflict
	USER_NAME_IN_USE = 409001,
}

/**
 * This is the shared TrueCar exception definition for general use in APIs.  It
 * provides a standard error code with an optional text message.
 */
exception ApiException {
	1: required i32 errorCode,
	2: optional string errorMessage,
    3: optional string debugMessage, 
}
