/*
 * This file provides definitions for temporal data types.
 */
 
namespace java com.truecar.thrift.type
namespace cocoa TCThrift




/**
 * Date/time is always stored as a signed 64-bit value representing the number of milliseconds since the Unix epoch
 * (1 January 1970).  Time representation is always in UTC (Universal Coordinated Time).  This type is used for timestamps.
 */
typedef i64 DateTimeMillis

/**
 * Dates are represented in the same for as date/time: a signed 64-bit value representing the number of milliseconds
 * since the Unix epoch (1 January 1970).  Time representation is always in UTC (Universal Coordinated Time).  By
 * convention, the time portion of the value MUST translate to 00:00:00.000.
 */
typedef i64 DateMillis

/**
 * Representation of a "raw" year, as used in models, for example.
 */
typedef i16 Year


/**
 * In ISO 8601 formatted day with time and UTC timezone set with "Z".  Formatted "YYYY-MM-DDThh:mm:ss.sTZD" (Example: 1970-01-01T00:00:00.000Z)
 */
typedef string DateTimeIsoString

/**
 * In ISO 8601 formatted day without time.  Formatted "yyyy-MM-dd" (Example: 1997-07-16)
 */
typedef string DateIsoString

/**
 *	Open and close times for a single day.
 */
struct DailyHoursOfOperation
{
	/**
	 *	Open time (HH:MM).
	 */
	1:optional string openTime,
	
	/**
	 *	Close time (HH:MM).
	 */
	2:optional string closeTime,
}

/**
 *	Open and close times for a whole week.
 *
 *	Also identifies the timezone of the location by a UTC offset and a DST observance flag.
 */
struct HoursOfOperation
{
	/**
	 *	Hours of operation for Monday.
	 */
	1:optional DailyHoursOfOperation mondayHours,

	/**
	 *	Hours of operation for Tuesday.
	 */
	2:optional DailyHoursOfOperation tuesdayHours,

	/**
	 *	Hours of operation for Wednesday.
	 */
	3:optional DailyHoursOfOperation wednesdayHours,

	/**
	 *	Hours of operation for Thursday.
	 */
	4:optional DailyHoursOfOperation thursdayHours,

	/**
	 *	Hours of operation for Friday.
	 */
	5:optional DailyHoursOfOperation fridayHours,

	/**
	 *	Hours of operation for Saturday.
	 */
	6:optional DailyHoursOfOperation saturdayHours,

	/**
	 *	Hours of operation for Sunday.
	 */
	7:optional DailyHoursOfOperation sundayHours,

	/**
	 *	Time zone offset from UTC in milliseconds.
	 */
	8:optional i32 utcOffsetMillis,

	/**
	 *	Flag to indicate observance of DST.
	 */
	9:optional bool daylightSavingsTimeObserver,
}
